HandlebarsEngine

Struct HandlebarsEngine 

pub struct HandlebarsEngine {
    pub sources: Vec<Box<dyn Source + Send + Sync>>,
    pub registry: RwLock<Box<Handlebars<'static>>>,
}
The handlebars template engine

Fields

sources: Vec<Box<dyn Source + Send + Sync>>registry: RwLock<Box<Handlebars<'static>>>

Implementations

Source

impl HandlebarsEngine

pub fn new() -> HandlebarsEngine

create a handlebars template engine

pub fn from(reg: Handlebars<'static>) -> HandlebarsEngine

create a handlebars template engine from existed handlebars registry

pub fn add(&mut self, source: Box<dyn Source + Send + Sync>)

add a template source

pub fn reload(&self) -> Result<(), SourceError>

load template from registered sources

pub fn handlebars_mut(&self) -> RwLockWriteGuard<'_, Box<Handlebars<'static>>>

access internal handlebars registry, useful to register custom helpers